from npqtools.problems.Clique.QuboClique import QUBOClique
from npqtools.problems.Hamiltonian.QuboHam import QUBOHam
from npqtools.problems.Knapsack.QuboKnapsack import QUBOKnapsack
from npqtools.problems.MaxWeightClique.QuboMaxWeightClique import QUBOMaxWeightClique
from npqtools.problems.Salesman.QuboSalesman import QUBOSalesman

